@@ -10,7 +10,7 @@ import requests
 from fake_headers import Headers
 
 
-class BaseSchoolClient():
+class BaseUserClient():
     BASE_URL = ""
     _http = requests.Session()
 
@@ -31,7 +31,6 @@ class BaseSchoolClient():
             url = f'{self.BASE_URL}{url_or_endpoint}'
         else:
             url = url_or_endpoint
-        
         res = self._http.request(
             method=method,
             url = url,
@@ -48,3 +47,4 @@ class BaseSchoolClient():
     def _update_headers(self, headers_dict):
         self._http.headers.update(headers_dict)
     
+
